@@ -3,12 +3,13 @@ from . import docx, conversion, options, documents, images, underline
 __all__ = ["convert_to_html", "extract_raw_text", "images", "underline"]
 
 
-def convert_to_html(fileobj, transform_document=None, **kwargs):
+def convert_to_html(fileobj, transform_document=None, generate_uniquifier=None, **kwargs):
     if transform_document is None:
         transform_document = lambda x: x
     return docx.read(fileobj).map(transform_document).bind(lambda document: 
         conversion.convert_document_element_to_html(
             document,
+            generate_uniquifier=generate_uniquifier,
             **options.read_options(kwargs)
         )
     )
